from django.apps import AppConfig


class NeurobankConfig(AppConfig):
    name = "nbank_registry"
